@@ -1,24 +1,12 @@
 package KinoSearchX::Simple;
 
-our $VERSION = '0.007';
-$VERSION = eval $VERSION;
+our $VERSION = '0.02';
 
 use 5.008;
 
 use Moose;
 use namespace::autoclean;
 
-use Moose::Util::TypeConstraints;
-
-subtype 'LoadClass' 
-    => as 'ClassName';
-
-coerce 'LoadClass' 
-    => from 'Str'
-    => via { Class::MOP::load_class($_); $_ };
-
-no Moose::Util::TypeConstraints;
-
 use KinoSearch1::InvIndexer;
 use KinoSearch1::Searcher;
 use KinoSearch1::Analysis::PolyAnalyzer;
@@ -26,8 +14,55 @@ use KinoSearch1::Index::Term;
 use KinoSearch1::QueryParser::QueryParser;
 use KinoSearch1::Search::TermQuery;
 
+use KinoSearchX::Simple::Result;
+
 use Data::Page;
 
+=pod
+
+=head1 NAME
+
+KinoSearchX::Simple - Simple L<KinoSearch1> Interface, inspired by L<Plucene::Simple>
+
+=head1 SYNOPSIS
+
+    use KinoSearchX::Simple;
+
+    my $searcher = KinoSearchX::Simple->new(
+        'index_path' => '/tmp/search_index',
+        'schema' => [
+            {
+                'name' => 'title',
+                'boost' => 3,
+            },{
+                'name' => 'description',
+            },{
+                'name' => 'id',
+            },
+        ],
+        'search_fields' => ['title', 'description'],
+        'search_boolop' => 'AND',
+    );
+
+    $searcher->create({
+        'id' => 1,
+        'title' => 'fibble',
+        'description' => 'wibble',
+    });
+
+    #important - always commit after updating the index!
+    $searcher->commit;
+
+    my ( $results, $pager ) = $searcher->search( 'fibble' );
+
+=head1 DESCRIPTION
+
+Simple interface to L<KinoSearch1>. Use if you want to use L<KinoSearch1> and are lazy :p
+
+=head1 FUNCTIONS
+
+=cut
+
 has _language => (
     'is' => 'ro',
     'isa' => 'Str',
@@ -113,18 +148,17 @@ sub _build__query_parser{
     my $self = shift;
 
     return KinoSearch1::QueryParser::QueryParser->new(
-        'analyzer'       => $self->_analyser,
-        'fields'         => $self->search_fields,
-        'default_boolop' => $self->search_boolop,
+        analyzer       => $self->_analyser,
+        fields         => $self->search_fields,
+        default_boolop => $self->search_boolop,
     );
 }
 
 has resultclass => (
     'is' => 'rw',
-    'isa' => 'LoadClass',
-    'coerce' => 1,
+    'isa' => 'ClassName',
     'lazy' => 1,
-    'default' => 'KinoSearchX::Simple::Result::Object',
+    'default' => 'KinoSearchX::Simple::Result',
 );
 
 has entries_per_page => (
@@ -136,6 +170,13 @@ has entries_per_page => (
 
 no Moose;
 
+=pod
+
+=head2 B<search>( $query_string, $page ) - search index
+
+    my ( $results, $pager ) = $searcher->search( $query, $page );
+
+=cut
 sub search{
     my ( $self, $query_string, $page ) = @_;
 
@@ -157,6 +198,17 @@ sub search{
     return undef;
 }
 
+=pod
+
+=head2 B<create>( $document ) - add item to index
+
+    $searcher->create({
+        'id' => 1,
+        'title' => 'this is the title',
+        'description' => 'this is the description',
+    });
+
+=cut
 sub create{
     my ( $self, $document ) = @_;
 
@@ -172,31 +224,59 @@ sub create{
     $self->_indexer->add_doc($doc);
 }
 
+=pod
+
+=head2 B<update_or_create>( $document, $pk, $pv ) - updates or creates document in the index
+
+    $searcher->update_or_create({
+        'id' => 1,
+        'title' => 'this is the updated title',
+        'description' => 'this is the description',
+    }, 'id', 1);
+
+$pk defaults to 'id'
+$pv defaults to $document->{'id'} if not provided
+
+=cut
 sub update_or_create{
-    my ( $self, $document, $pk ) = @_;
+    my ( $self, $document, $pk, $pv ) = @_;
 
-    return undef if ( !$document );
     $pk ||= 'id';
-    my $pv = $document->{ $pk };
+    $pv ||= $document->{'id'};
 
-    return undef if ( !$pv );
+    return undef if ( !$document || !$pk );
     $self->delete( $pk, $pv );
-    $self->commit;
 
     $self->create( $document );
 }
 
+=pod
+
+=head2 B<delete>( $key, $value ) - remove document from the index
+
+    $searcher->delete( 'id', 1 );
+
+finds $key with $value and removes from index
+
+=cut
 sub delete{
     my ( $self, $key, $value ) = @_;
 
     return undef if ( !$key || !$value );
 
-    #delete only works on finished indexes
-    $self->commit;
     my $term = KinoSearch1::Index::Term->new( $key => $value );
     $self->_indexer->delete_docs_by_term($term);
 }
 
+=pod
+
+=head2 B<commit>() - commits and optimises index after adding documents
+
+    $searcher->commit();
+
+you must call this after you have finished adding items to the index
+
+=cut
 sub commit{
     my ( $self ) = @_;
 
@@ -208,88 +288,6 @@ sub commit{
     $self->_clear_searcher;
 }
 
-__PACKAGE__->meta->make_immutable;
-
-=head1 NAME
-
-KinoSearchX::Simple - Simple L<KinoSearch1> Interface
-
-=head1 SYNOPSIS
-
-    use KinoSearchX::Simple;
-
-    my $searcher = KinoSearchX::Simple->new(
-        'index_path' => '/tmp/search_index',
-        'schema' => [
-            {
-                'name' => 'title',
-                'boost' => 3,
-            },{
-                'name' => 'description',
-            },{
-                'name' => 'id',
-                'analysed' => 0, #you don't want the analyser to adjust your id do you?
-            },
-        ],
-        'search_fields' => ['title', 'description'],
-        'search_boolop' => 'AND',
-    );
-
-    $searcher->create({
-        'id' => 1,
-        'title' => 'fibble',
-        'description' => 'wibble',
-    });
-
-    #important - always commit after updating the index!
-    $searcher->commit;
-
-    my ( $results, $pager ) = $searcher->search( 'fibble' );
-
-=head1 DESCRIPTION
-
-Simple interface to L<KinoSearch1>. Use if you want to use L<KinoSearch1> and are lazy :p
-
-=head1 METHODS
-
-=head2 B<search>( $query_string, $page ) - search index
-
-    my ( $results, $pager ) = $searcher->search( $query, $page );
-
-=head2 B<create>( $document ) - add item to index
-
-    $searcher->create({
-        'id' => 1,
-        'title' => 'this is the title',
-        'description' => 'this is the description',
-    });
-
-not that it has to be, but its highly recommended that I<id> is a unique identifier for this document 
-
-or you'll have to pass $pk to update_or_create
-
-=head2 B<update_or_create>( $document, $pk ) - updates or creates document in the index
-
-    $searcher->update_or_create({
-        'id' => 1,
-        'title' => 'this is the updated title',
-        'description' => 'this is the description',
-    }, 'id');
-
-$pk is the unique key to lookup by, defaults to 'id'
-
-=head2 B<delete>( $key, $value ) - remove document from the index
-
-    $searcher->delete( 'id', 1 );
-
-finds $key with $value and removes from index
-
-=head2 B<commit>() - commits and optimises index after adding documents
-
-    $searcher->commit();
-
-you must call this after you have finished doing things to the index
-
 =head1 ADVANCED
 
 when creating the KinoSearchX::Simple object you can specify some advanced options
@@ -324,18 +322,20 @@ can be changed to I<AND>, in which case the above becomes
 
 =head2 resultclass
 
-resultclass for results, defaults to L<KinoSearchX::Simple::Result::Object> which creates acessors for each key => value returned
-
-could be changed tp KinoSearchX::Simple::Result::Hash for a plain old, hashref or a custom class
+resultclass for results, defaults to L<KinoSearchX::Simple::Result> which creates acessors for each key => value returned
 
 =head2 entries_per_page
 
 default is 100
 
+=cut
+
 =head1 SUPPORT
 
 Bugs should always be submitted via the CPAN bug tracker
 
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=KinoSearchX-Simple>
+
 For other issues, contact the maintainer
 
 =head1 AUTHORS
@@ -344,13 +344,16 @@ n0body E<lt>n0body@thisaintnews.comE<gt>
 
 =head1 SEE ALSO
 
-L<http://thisaintnews.com>, L<Image::Info>
+L<http://thisaintnews.com>, L<KinoSearch1>, L<Data::Page>, L<Moose>
 
-=head1 LICENSE
+=head1 COPYRIGHT
 
-Copyright (C) 2011 by n0body L<http://thisaintnews.com/>
+Copyright 2010 n0body L<http://thisaintnews.com/> . All rights reserved.
 
-This library is free software, you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This program is free software; you can redistribute
+it and/or modify it under the same terms as perl itself.
 
 =cut
+
+
+__PACKAGE__->meta->make_immutable;
